Install
=======

- Python version >= 3.8
- xsdata version == 21.9

.. code-block:: bash

    pip install gexfpy


Install from source via:

.. code-block:: bash

    pip install git+https://github.com/chunqishi/gexfpy.git


Or clone the repository and install with the following commands:

.. code-block:: bash

    git clone git@github.com:chunqishi/gexfpy.git
    cd gexfpy
    pip install -e .